package org.hackystat.ambientdevice.device.bunny;

import java.util.logging.Logger;
import org.hackystat.ambientdevice.ConfigurationException;
import org.hackystat.ambientdevice.device.AmbientAction;
import org.hackystat.ambientdevice.device.bunny.Nabaztag.EarPosition;

/**
 * A class to move the right ear.
 * 
 * @author Sonny Gomez
 */
public class ChangeRightEarPosition implements AmbientAction {
  /** the Nabaztag that will change its ear positions. */
  private Nabaztag nabaztag;
  /** the left Ear Position for the Nabaztag bunny. */
  private EarPosition rightPos;
  /** Logger. **/
  private Logger logger = Logger.getLogger("org.hackystat.ambientdevice");

  /**
   * Constructor for ChangeLeftEarPosition.
   * @param nabaztag containing the Nabaztag bunny.
   * @param rightPos containing the position of the left ear.
   * @throws ConfigurationException if Unsupported value is given.
   */
  public ChangeRightEarPosition(Nabaztag nabaztag, String rightPos) throws ConfigurationException {
    this.nabaztag = nabaztag;
    this.rightPos = EarPosition.getEnumValue(rightPos);
    if (this.rightPos == EarPosition.Unsupported) {
      throw new ConfigurationException("Ear Position" + rightPos + " not supported by Nabaztag.");
    }
  }

  /**
   * Change the bunny's right ear position according to data given.
   */
  public void act() {
    logger.info("Change Nabaztag's Right Ear Position to " + rightPos);
    nabaztag.setRightPos(rightPos);
    nabaztag.updateRightEarState();
  }

  /**
   * @return the Nabaztag bunny.
   */
  public Nabaztag getNabaztag() {
    return this.nabaztag;
  }

  /**
   * @return the left ear position.
   */
  public EarPosition getRightEarPosition() {
    return this.rightPos;
  }
}
